==> bitcoin-0.20.1.tar.gz: bitcoin-0.20.1/src/qt/locale/bitcoin_my.ts <==
<TS language="my" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>လိပ်စာ သို့မဟုတ် ခေါင်းစဉ်တပ်ရန် Right-click နှိပ်ပါ။</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>လိပ်စာအသစ်ယူမယ်။</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;အသစ်</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>လက်ရှိရွေးထားတဲ့ လိပ်စာကို clipboard ပေါ်တင်မယ်။</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;ကူးမယ်</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>လက်ရှိရွေးထားတဲ့ လိပ်စာကို ဖျက်မယ်။</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>လက်ရှိ tab မှာရှိတဲ့ဒေတာတွေကို ဖိုင်လ်မှာသိမ်းမယ်။</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;ထုတ်ယူသိမ်းဆည်း</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;ဖျက်</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;ထုတ်ယူသိမ်းဆည်း</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>လက်ရှိ tab မှာရှိတဲ့ဒေတာတွေကို ဖိုင်လ်မှာသိမ်းမယ်။</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>

==> bitcoin-0.21.2.tar.gz: bitcoin-0.21.2/src/qt/locale/bitcoin_my.ts <==
<TS language="my" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>လိပ်စာ သို့မဟုတ် ခေါင်းစဉ်တပ်ရန် Right-click နှိပ်ပါ။</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>လိပ်စာအသစ်ယူမယ်။</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;အသစ်</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>လက်ရှိရွေးထားတဲ့ လိပ်စာကို clipboard ပေါ်တင်မယ်။</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;ကူးမယ်</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>လက်ရှိရွေးထားတဲ့ လိပ်စာကို ဖျက်မယ်။</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>လိပ်စာရိုက်ထည့်ပါ</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>လက်ရှိ tab မှာရှိတဲ့ဒေတာတွေကို ဖိုင်လ်မှာသိမ်းမယ်။</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;ထုတ်ယူသိမ်းဆည်း</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;ဖျက်</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>လိပ်စာကိုပေးပို့ဖို့လိပ်စာရွေးချယ်ပါ</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>လိပ်စာပေးပို့နေသည်</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>လိပ်စာလက်ခံရရှိသည်</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>တင်ပို့မှုမအောင်မြင်ပါ</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>တံဆိပ်</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>လိပ်စာ</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Error</source>
        <translation>အမှား</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>သတိပေးချက်</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>အချက်အလက်</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>နောက်ဆုံးပေါ်</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>ချဲ့</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Date</source>
        <translation>နေ့စွဲ</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>ဟုတ်တယ်</translation>
    </message>
    <message>
        <source>no</source>
        <translation>မဟုတ်ဘူး</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>အမှား</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Error</source>
        <translation>အမှား</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>နေ့စွဲ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>တံဆိပ်</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>နေ့စွဲ</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>နေ့စွဲ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>တံဆိပ်</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Date</source>
        <translation>နေ့စွဲ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>တံဆိပ်</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>လိပ်စာ</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>တင်ပို့မှုမအောင်မြင်ပါ</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;ထုတ်ယူသိမ်းဆည်း</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>လက်ရှိ tab မှာရှိတဲ့ဒေတာတွေကို ဖိုင်လ်မှာသိမ်းမယ်။</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>အမှား</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>
